@@ -30,7 +30,8 @@ class DConnectApp(Daemon):
             IntEntry('uin', 'Unique identifier of device in network', False, 1, 0xFFFFFFF, randint(0, 1024)),
             StringEntry('name', 'Name of device in network', False, 1, 60, socket.gethostname()),
             StringEntry('description', 'Arbitrary description of device', False, 0, 200, ''),
-            StringEntry('password', 'Password to access to device from clients', False, 0, 4096, 'password'),
+            StringEntry('password', 'Password to access to device from clients', False, 0, 4096,
+                        default=''.join(tuple(chr(randint(ord('a'), ord('z'))) for _ in range(10)))),
         )),
         IntEntry('port', 'Port for UDP and TCP sockets', False, 1, 0xFFFF, 5040),
         FileEntry('pidfile', 'Path to pidfile for daemon mode', True, '', False, False)
@@ -77,7 +78,7 @@ class DConnectApp(Daemon):
         self.udp_thread = self.tcp_thread = None
 
     def init_environment(self):
-        """Load environment variables"""
+        """Load environment variables, add some local variables and set current directory to config dir"""
         env = {k: v for k, v in os.environ.items()}
         xdg_runtime_dir = env.get('XDG_RUNTIME_DIR', os.path.join('/', 'var', 'run', 'user', str(os.getuid())))
         if not os.path.isdir(xdg_runtime_dir):
@@ -89,6 +90,7 @@ class DConnectApp(Daemon):
             os.makedirs(runtime_dir, exist_ok=True)
         self.xdg_runtime_dir = xdg_runtime_dir
         env['DCNNT_RUNTIME_DIR'] = runtime_dir
+        env['DCNNT_CONFIG_DIR'] = self.directory
         return env
 
     def init_logger(self):
